==> python-softlayer_4.1.1.orig.tar.gz: softlayer-python-4.1.1/SoftLayer/fixtures/SoftLayer_Product_Package.py <==
HARDWARE_ITEMS = [
    {'attributes': [],
     'capacity': '999',
     'description': 'Unknown',
     'itemCategory': {'categoryCode': 'unknown', 'id': 325},
     'keyName': 'UNKNOWN',
     'prices': [{'accountRestrictions': [],
                 'currentPriceFlag': '',
                 'hourlyRecurringFee': '0',
                 'id': 1245172,
                 'itemId': 935954,
                 'laborFee': '0',
                 'onSaleFlag': '',
                 'oneTimeFee': '0',
                 'quantity': '',
                 'recurringFee': '0',
                 'setupFee': '0',
                 'sort': 0}]},
    {'attributes': [],
     'capacity': '64',
     'description': '1 IPv6 Address',
     'itemCategory': {'categoryCode': 'pri_ipv6_addresses',
                      'id': 325},
     'keyName': '1_IPV6_ADDRESS',
     'prices': [{'accountRestrictions': [],
                 'currentPriceFlag': '',
                 'hourlyRecurringFee': '0',
                 'id': 17129,
                 'itemId': 4097,
                 'laborFee': '0',
                 'onSaleFlag': '',
                 'oneTimeFee': '0',
                 'quantity': '',
                 'recurringFee': '0',
                 'setupFee': '0',
                 'sort': 0}]},
    {'attributes': [],
     'capacity': '10',
     'description': '10 Mbps Public & Private Network Uplinks',
     'itemCategory': {'categoryCode': 'port_speed', 'id': 26},
     'keyName': '10_MBPS_PUBLIC_PRIVATE_NETWORK_UPLINKS',
     'prices': [{'accountRestrictions': [],
                 'currentPriceFlag': '',
                 'hourlyRecurringFee': '0',
                 'id': 272,
                 'itemId': 186,
                 'laborFee': '0',
                 'onSaleFlag': '',
                 'oneTimeFee': '0',
                 'quantity': '',
                 'recurringFee': '0',
                 'setupFee': '0',
                 'sort': 5}]},
    {'attributes': [],
     'capacity': '0',
     'description': 'Ubuntu Linux 14.04 LTS Trusty Tahr (64 bit)',
     'itemCategory': {'categoryCode': 'os', 'id': 12},
     'keyName': 'OS_UBUNTU_14_04_LTS_TRUSTY_TAHR_64_BIT',
     'prices': [{'accountRestrictions': [],
                 'currentPriceFlag': '',
                 'hourlyRecurringFee': '0',
                 'id': 37650,
                 'itemId': 4702,
                 'laborFee': '0',
                 'onSaleFlag': '',
                 'oneTimeFee': '0',
                 'quantity': '',
                 'recurringFee': '0',
                 'setupFee': '0',
                 'sort': 9}],
     'softwareDescription': {'id': 1362,
                             'longDescription': 'Ubuntu / 14.04-64',
                             'referenceCode': 'UBUNTU_14_64'}},
    {'attributes': [],
     'capacity': '1',
     'description': '1 IP Address',
     'itemCategory': {'categoryCode': 'pri_ip_addresses', 'id': 13},
     'keyName': '1_IP_ADDRESS',
     'prices': [{'accountRestrictions': [],
                 'currentPriceFlag': '',
                 'hourlyRecurringFee': '0',
                 'id': 21,
                 'itemId': 15,
                 'laborFee': '0',
                 'onSaleFlag': '',
                 'oneTimeFee': '0',
                 'quantity': '',
                 'recurringFee': '0',
                 'setupFee': '0',
                 'sort': 0}]},
    {'attributes': [{'attributeTypeKeyName': 'RECLAIM_BYPASS',
                     'id': 1014}],
     'description': 'Unlimited SSL VPN Users',
     'itemCategory': {'categoryCode': 'vpn_management', 'id': 31},
     'keyName': 'SSL_VPN_USERS_1_PPTP_VPN_USER_PER_ACCOUNT',
     'prices': [{'accountRestrictions': [],
                 'currentPriceFlag': '',
                 'hourlyRecurringFee': '0',
                 'id': 420,
                 'itemId': 309,
                 'laborFee': '0',
                 'onSaleFlag': '',
                 'oneTimeFee': '0',
                 'quantity': '',
                 'recurringFee': '0',
                 'setupFee': '0',
                 'sort': 0}]},
    {'attributes': [],
     'description': 'Reboot / KVM over IP',
     'itemCategory': {'categoryCode': 'remote_management',
                      'id': 46},
     'keyName': 'REBOOT_KVM_OVER_IP',
     'prices': [{'accountRestrictions': [],
                 'currentPriceFlag': '',
                 'hourlyRecurringFee': '0',
                 'id': 906,
                 'itemId': 504,
                 'laborFee': '0',
                 'onSaleFlag': '',
                 'oneTimeFee': '0',
                 'quantity': '',
                 'recurringFee': '0',
                 'setupFee': '0',
                 'sort': 0}]},
    {'attributes': [],
     'capacity': '0',
     'description': '0 GB Bandwidth',
     'itemCategory': {'categoryCode': 'bandwidth', 'id': 10},
     'keyName': 'BANDWIDTH_0_GB',
     'prices': [{'accountRestrictions': [],
                 'currentPriceFlag': '',
                 'id': 22505,
                 'itemId': 4481,
                 'laborFee': '0',
                 'onSaleFlag': '',
                 'oneTimeFee': '0',
                 'quantity': '',
                 'recurringFee': '0',
                 'setupFee': '0',
                 'sort': 98}]},
    {'attributes': [],
     'capacity': '0',
     'description': '0 GB Bandwidth',
     'itemCategory': {'categoryCode': 'bandwidth', 'id': 10},
     'keyName': 'BANDWIDTH_0_GB_2',
     'prices': [{'accountRestrictions': [],
                 'currentPriceFlag': '',
                 'hourlyRecurringFee': '0',
                 'id': 1800,
                 'itemId': 439,
                 'laborFee': '0',
                 'onSaleFlag': '',
                 'oneTimeFee': '0',
                 'quantity': '',
                 'setupFee': '0',
                 'sort': 99}]}]


getAllObjects = [{
    'activePresets': [{
        'description': 'Single Xeon 1270, 8GB Ram, 2x1TB SATA disks, Non-RAID',
        'id': 64,
        'isActive': '1',
        'keyName': 'S1270_8GB_2X1TBSATA_NORAID',
        'name': 'S1270 8GB 2X1TBSATA NORAID',
        'packageId': 200
    }],
    'description': 'Bare Metal Server',
    'firstOrderStepId': 1,
    'id': 200,
    'isActive': 1,
    'items': HARDWARE_ITEMS,
    'name': 'Bare Metal Server',
    'regions': [{'description': 'WDC01 - Washington, DC - East Coast U.S.',
                 'keyname': 'WASHINGTON_DC',
                 'location': {'location': {'id': 37473,
                                           'longName': 'Washington 1',
                                           'name': 'wdc01'}},
                 'sortOrder': 10}],
    'subDescription': 'Bare Metal Server',
    'unitSize': 1,
}]

getItems = [
    {
        'id': 1234,
        'capacity': '1000',
        'description': 'Public & Private Networks',
        'itemCategory': {'categoryCode': 'Uplink Port Speeds'},
        'prices': [{'id': 1122,
                    'categories': [{'id': 26, 'name': 'Uplink Port Speeds'}]}],
    },
    {
        'id': 2233,
        'capacity': '1000',
        'description': 'Public & Private Networks',
        'itemCategory': {'categoryCode': 'Uplink Port Speeds'},
        'prices': [{'id': 4477,
                    'categories': [{'id': 26, 'name': 'Uplink Port Speeds'}]}],
    },
    {
        'id': 1239,
        'capacity': '2',
        'description': 'RAM',
        'itemCategory': {'categoryCode': 'RAM'},
        'prices': [{'id': 1133,
                    'categories': [{'id': 3, 'name': 'RAM'}]}],
    },
    {
        'id': 1240,
        'capacity': '4',
        'description': 'Private Computing Instance',
        'itemCategory': {'categoryCode': 'Computing Instance'},
        'prices': [{'id': 1007,
                    'categories': [{'id': 80, 'name': 'Computing Instance'}]}],
    },
    {
        'id': 1250,
        'capacity': '4',
        'description': 'Computing Instance',
        'itemCategory': {'categoryCode': 'Computing Instance'},
        'prices': [{'id': 1144,
                    'categories': [{'id': 80, 'name': 'Computing Instance'}]}],
    },
    {
        'id': 4439,
        'capacity': '1',
        'description': '1 GB iSCSI Storage',
        'itemCategory': {'categoryCode': 'iscsi'},
        'prices': [{'id': 2222}],
    },
    {
        'id': 1121,
        'capacity': '20',
        'description': '20 GB iSCSI snapshot',
        'itemCategory': {'categoryCode': 'iscsi_snapshot_space'},
        'prices': [{'id': 2014}],
    },
    {
        'id': 4440,
        'capacity': '4',
        'description': '4 Portable Public IP Addresses',
        'itemCategory': {'categoryCode': 'sov_sec_ip_addresses_pub'},
        'prices': [{'id': 4444}],
    },
    {
        'id': 8880,
        'capacity': '8',
        'description': '8 Portable Public IP Addresses',
        'itemCategory': {'categoryCode': 'sov_sec_ip_addresses_pub'},
        'prices': [{'id': 8888}],
    },
    {
        'id': 44400,
        'capacity': '4',
        'description': '4 Portable Private IP Addresses',
        'itemCategory': {'categoryCode': 'sov_sec_ip_addresses_priv'},
        'prices': [{'id': 44441}],
    },
    {
        'id': 88800,
        'capacity': '8',
        'description': '8 Portable Private IP Addresses',
        'itemCategory': {'categoryCode': 'sov_sec_ip_addresses_priv'},
        'prices': [{'id': 88881}],
    },
    {
        'id': 10,
        'capacity': '0',
        'description': 'Global IPv4',
        'itemCategory': {'categoryCode': 'global_ipv4'},
        'prices': [{'id': 11}],
    },
    {
        'id': 66464,
        'capacity': '64',
        'description': '/64 Block Portable Public IPv6 Addresses',
        'itemCategory': {'categoryCode': 'static_ipv6_addresses'},
        'prices': [{'id': 664641}],
    },
    {
        'id': 610,
        'capacity': '0',
        'description': 'Global IPv6',
        'itemCategory': {'categoryCode': 'global_ipv6'},
        'prices': [{'id': 611}],
    }]


getItemPrices = [
    {
        'currentPriceFlag': '',
        'id': 2152,
        'item': {
            'capacity': '1',
            'description': '1 GB iSCSI SAN Storage',
            'id': 1111,
            'softwareDescriptionId': '',
            'units': 'GB',
            'upgradeItemId': 547},
        'itemId': 1111,
        'laborFee': '0',
        'onSaleFlag': '',
        'oneTimeFee': '0',
        'packageReferences': [{'id': 46626,
                               'itemPriceId': 2152, 'packageId': 0}],
        'quantity': '',
        'recurringFee': '.35',
        'setupFee': '0',
        'sort': 0
    },
    {
        'currentPriceFlag': '',
        'id': 22501,
        'item': {'capacity': '1',
                 'description': '1 GB iSCSI SAN Storage',
                 'id': 1111,
                 'softwareDescriptionId': '',
                 'units': 'GB',
                 'upgradeItemId': 547},
        'itemId': 1111,
        'laborFee': '0',
        'onSaleFlag': '',
        'oneTimeFee': '0',
        'packageReferences': [{
            'id': 252983,
            'itemPriceId': 22501, 'packageId': 0
        }],
        'quantity': '',
        'recurringFee': '0',
        'setupFee': '0',
        'sort': 0
    },
    {
        'currentPriceFlag': '',
        'id': 22441,
        'item': {
            'capacity': '1',
            'description': '1 GB iSCSI SAN Storage',
            'id': 1111,
            'softwareDescriptionId': '',
            'units': 'GB',
            'upgradeItemId': 547
        },
        'itemId': 1111,
        'laborFee': '0',
        'onSaleFlag': '',
        'oneTimeFee': '0',
        'packageReferences': [{'id': 250326,
                               'itemPriceId': 22441, 'packageId': 0}],
        'quantity': '',
        'recurringFee': '15',
        'setupFee': '0',
        'sort': 0
    }]

==> python-softlayer_5.2.1.orig.tar.gz: softlayer-python-5.2.1/SoftLayer/fixtures/SoftLayer_Product_Package.py <==
HARDWARE_ITEMS = [
    {'attributes': [],
     'capacity': '999',
     'description': 'Unknown',
     'itemCategory': {'categoryCode': 'unknown', 'id': 325},
     'keyName': 'UNKNOWN',
     'prices': [{'accountRestrictions': [],
                 'currentPriceFlag': '',
                 'hourlyRecurringFee': '0',
                 'id': 1245172,
                 'itemId': 935954,
                 'laborFee': '0',
                 'onSaleFlag': '',
                 'oneTimeFee': '0',
                 'quantity': '',
                 'recurringFee': '0',
                 'setupFee': '0',
                 'sort': 0}]},
    {'attributes': [],
     'capacity': '64',
     'description': '1 IPv6 Address',
     'itemCategory': {'categoryCode': 'pri_ipv6_addresses',
                      'id': 325},
     'keyName': '1_IPV6_ADDRESS',
     'prices': [{'accountRestrictions': [],
                 'currentPriceFlag': '',
                 'hourlyRecurringFee': '0',
                 'id': 17129,
                 'itemId': 4097,
                 'laborFee': '0',
                 'onSaleFlag': '',
                 'oneTimeFee': '0',
                 'quantity': '',
                 'recurringFee': '0',
                 'setupFee': '0',
                 'sort': 0}]},
    {'attributes': [],
     'capacity': '10',
     'description': '10 Mbps Public & Private Network Uplinks',
     'itemCategory': {'categoryCode': 'port_speed', 'id': 26},
     'keyName': '10_MBPS_PUBLIC_PRIVATE_NETWORK_UPLINKS',
     'prices': [{'accountRestrictions': [],
                 'currentPriceFlag': '',
                 'hourlyRecurringFee': '0',
                 'id': 272,
                 'itemId': 186,
                 'laborFee': '0',
                 'onSaleFlag': '',
                 'oneTimeFee': '0',
                 'quantity': '',
                 'recurringFee': '0',
                 'setupFee': '0',
                 'sort': 5}]},
    {'attributes': [],
     'capacity': '0',
     'description': 'Ubuntu Linux 14.04 LTS Trusty Tahr (64 bit)',
     'itemCategory': {'categoryCode': 'os', 'id': 12},
     'keyName': 'OS_UBUNTU_14_04_LTS_TRUSTY_TAHR_64_BIT',
     'prices': [{'accountRestrictions': [],
                 'currentPriceFlag': '',
                 'hourlyRecurringFee': '0',
                 'id': 37650,
                 'itemId': 4702,
                 'laborFee': '0',
                 'onSaleFlag': '',
                 'oneTimeFee': '0',
                 'quantity': '',
                 'recurringFee': '0',
                 'setupFee': '0',
                 'sort': 9}],
     'softwareDescription': {'id': 1362,
                             'longDescription': 'Ubuntu / 14.04-64',
                             'referenceCode': 'UBUNTU_14_64'}},
    {'attributes': [],
     'capacity': '1',
     'description': '1 IP Address',
     'itemCategory': {'categoryCode': 'pri_ip_addresses', 'id': 13},
     'keyName': '1_IP_ADDRESS',
     'prices': [{'accountRestrictions': [],
                 'currentPriceFlag': '',
                 'hourlyRecurringFee': '0',
                 'id': 21,
                 'itemId': 15,
                 'laborFee': '0',
                 'onSaleFlag': '',
                 'oneTimeFee': '0',
                 'quantity': '',
                 'recurringFee': '0',
                 'setupFee': '0',
                 'sort': 0}]},
    {'attributes': [{'attributeTypeKeyName': 'RECLAIM_BYPASS',
                     'id': 1014}],
     'description': 'Unlimited SSL VPN Users',
     'itemCategory': {'categoryCode': 'vpn_management', 'id': 31},
     'keyName': 'SSL_VPN_USERS_1_PPTP_VPN_USER_PER_ACCOUNT',
     'prices': [{'accountRestrictions': [],
                 'currentPriceFlag': '',
                 'hourlyRecurringFee': '0',
                 'id': 420,
                 'itemId': 309,
                 'laborFee': '0',
                 'onSaleFlag': '',
                 'oneTimeFee': '0',
                 'quantity': '',
                 'recurringFee': '0',
                 'setupFee': '0',
                 'sort': 0}]},
    {'attributes': [],
     'description': 'Reboot / KVM over IP',
     'itemCategory': {'categoryCode': 'remote_management',
                      'id': 46},
     'keyName': 'REBOOT_KVM_OVER_IP',
     'prices': [{'accountRestrictions': [],
                 'currentPriceFlag': '',
                 'hourlyRecurringFee': '0',
                 'id': 906,
                 'itemId': 504,
                 'laborFee': '0',
                 'onSaleFlag': '',
                 'oneTimeFee': '0',
                 'quantity': '',
                 'recurringFee': '0',
                 'setupFee': '0',
                 'sort': 0}]},
    {'attributes': [],
     'capacity': '0',
     'description': '0 GB Bandwidth',
     'itemCategory': {'categoryCode': 'bandwidth', 'id': 10},
     'keyName': 'BANDWIDTH_0_GB',
     'prices': [{'accountRestrictions': [],
                 'currentPriceFlag': '',
                 'id': 22505,
                 'itemId': 4481,
                 'laborFee': '0',
                 'onSaleFlag': '',
                 'oneTimeFee': '0',
                 'quantity': '',
                 'recurringFee': '0',
                 'setupFee': '0',
                 'sort': 98}]},
    {'attributes': [],
     'capacity': '0',
     'description': '0 GB Bandwidth',
     'itemCategory': {'categoryCode': 'bandwidth', 'id': 10},
     'keyName': 'BANDWIDTH_0_GB_2',
     'prices': [{'accountRestrictions': [],
                 'currentPriceFlag': '',
                 'hourlyRecurringFee': '0',
                 'id': 1800,
                 'itemId': 439,
                 'laborFee': '0',
                 'onSaleFlag': '',
                 'oneTimeFee': '0',
                 'quantity': '',
                 'setupFee': '0',
                 'sort': 99}]}]


getAllObjects = [{
    'activePresets': [{
        'description': 'Single Xeon 1270, 8GB Ram, 2x1TB SATA disks, Non-RAID',
        'id': 64,
        'isActive': '1',
        'keyName': 'S1270_8GB_2X1TBSATA_NORAID',
        'name': 'S1270 8GB 2X1TBSATA NORAID',
        'packageId': 200
    }],
    'description': 'Bare Metal Server',
    'firstOrderStepId': 1,
    'id': 200,
    'isActive': 1,
    'items': HARDWARE_ITEMS,
    'name': 'Bare Metal Server',
    'regions': [{'description': 'WDC01 - Washington, DC - East Coast U.S.',
                 'keyname': 'WASHINGTON_DC',
                 'location': {'location': {'id': 37473,
                                           'longName': 'Washington 1',
                                           'name': 'wdc01'}},
                 'sortOrder': 10}],
    'subDescription': 'Bare Metal Server',
    'unitSize': 1,
}]

getItems = [
    {
        'id': 1234,
        'capacity': '1000',
        'description': 'Public & Private Networks',
        'itemCategory': {'categoryCode': 'Uplink Port Speeds'},
        'prices': [{'id': 1122,
                    'categories': [{'id': 26,
                                    'name': 'Uplink Port Speeds',
                                    'categoryCode': 'port_speed'}]}],
    },
    {
        'id': 2233,
        'capacity': '1000',
        'description': 'Public & Private Networks',
        'itemCategory': {'categoryCode': 'Uplink Port Speeds'},
        'prices': [{'id': 4477,
                    'categories': [{'id': 26,
                                    'name': 'Uplink Port Speeds',
                                    'categoryCode': 'port_speed'}]}],
    },
    {
        'id': 1239,
        'capacity': '2',
        'description': 'RAM',
        'itemCategory': {'categoryCode': 'RAM'},
        'prices': [{'id': 1133,
                    'categories': [{'id': 3,
                                    'name': 'RAM',
                                    'categoryCode': 'ram'}]}],
    },
    {
        'id': 1240,
        'capacity': '4',
        'description': 'Private Computing Instance',
        'itemCategory': {'categoryCode': 'Computing Instance'},
        'prices': [{'id': 1007,
                    'categories': [{'id': 80,
                                    'name': 'Computing Instance',
                                    'categoryCode': 'guest_core'}]}],
    },
    {
        'id': 1250,
        'capacity': '4',
        'description': 'Computing Instance',
        'itemCategory': {'categoryCode': 'Computing Instance'},
        'prices': [{'id': 1144,
                    'locationGroupId': None,
                    'categories': [{'id': 80,
                                    'name': 'Computing Instance',
                                    'categoryCode': 'guest_core'}]}],
    },
    {
        'id': 112233,
        'capacity': '55',
        'description': 'Computing Instance',
        'itemCategory': {'categoryCode': 'Computing Instance'},
        'prices': [{'id': 332211,
                    'locationGroupId': 1,
                    'categories': [{'id': 80,
                                    'name': 'Computing Instance',
                                    'categoryCode': 'guest_core'}]}],
    },
    {
        'id': 4439,
        'capacity': '1',
        'description': '1 GB iSCSI Storage',
        'itemCategory': {'categoryCode': 'iscsi'},
        'prices': [{'id': 2222}],
    },
    {
        'id': 1121,
        'capacity': '20',
        'description': '20 GB iSCSI snapshot',
        'itemCategory': {'categoryCode': 'iscsi_snapshot_space'},
        'prices': [{'id': 2014}],
    },
    {
        'id': 4440,
        'capacity': '4',
        'description': '4 Portable Public IP Addresses',
        'itemCategory': {'categoryCode': 'sov_sec_ip_addresses_pub'},
        'prices': [{'id': 4444}],
    },
    {
        'id': 8880,
        'capacity': '8',
        'description': '8 Portable Public IP Addresses',
        'itemCategory': {'categoryCode': 'sov_sec_ip_addresses_pub'},
        'prices': [{'id': 8888}],
    },
    {
        'id': 44400,
        'capacity': '4',
        'description': '4 Portable Private IP Addresses',
        'itemCategory': {'categoryCode': 'sov_sec_ip_addresses_priv'},
        'prices': [{'id': 44441}],
    },
    {
        'id': 88800,
        'capacity': '8',
        'description': '8 Portable Private IP Addresses',
        'itemCategory': {'categoryCode': 'sov_sec_ip_addresses_priv'},
        'prices': [{'id': 88881}],
    },
    {
        'id': 10,
        'capacity': '0',
        'description': 'Global IPv4',
        'itemCategory': {'categoryCode': 'global_ipv4'},
        'prices': [{'id': 11}],
    },
    {
        'id': 66464,
        'capacity': '64',
        'description': '/64 Block Portable Public IPv6 Addresses',
        'itemCategory': {'categoryCode': 'static_ipv6_addresses'},
        'prices': [{'id': 664641}],
    },
    {
        'id': 610,
        'capacity': '0',
        'description': 'Global IPv6',
        'itemCategory': {'categoryCode': 'global_ipv6'},
        'prices': [{'id': 611}],
    }]


getItemPrices = [
    {
        'currentPriceFlag': '',
        'id': 2152,
        'item': {
            'capacity': '1',
            'description': '1 GB iSCSI SAN Storage',
            'id': 1111,
            'softwareDescriptionId': '',
            'units': 'GB',
            'upgradeItemId': 547},
        'itemId': 1111,
        'laborFee': '0',
        'onSaleFlag': '',
        'oneTimeFee': '0',
        'packageReferences': [{'id': 46626,
                               'itemPriceId': 2152, 'packageId': 0}],
        'quantity': '',
        'recurringFee': '.35',
        'setupFee': '0',
        'sort': 0
    },
    {
        'currentPriceFlag': '',
        'id': 22501,
        'item': {'capacity': '1',
                 'description': '1 GB iSCSI SAN Storage',
                 'id': 1111,
                 'softwareDescriptionId': '',
                 'units': 'GB',
                 'upgradeItemId': 547},
        'itemId': 1111,
        'laborFee': '0',
        'onSaleFlag': '',
        'oneTimeFee': '0',
        'packageReferences': [{
            'id': 252983,
            'itemPriceId': 22501, 'packageId': 0
        }],
        'quantity': '',
        'recurringFee': '0',
        'setupFee': '0',
        'sort': 0
    },
    {
        'currentPriceFlag': '',
        'id': 22441,
        'item': {
            'capacity': '1',
            'description': '1 GB iSCSI SAN Storage',
            'id': 1111,
            'softwareDescriptionId': '',
            'units': 'GB',
            'upgradeItemId': 547
        },
        'itemId': 1111,
        'laborFee': '0',
        'onSaleFlag': '',
        'oneTimeFee': '0',
        'packageReferences': [{'id': 250326,
                               'itemPriceId': 22441, 'packageId': 0}],
        'quantity': '',
        'recurringFee': '15',
        'setupFee': '0',
        'sort': 0
    }]
